pub unsafe extern "C" fn LGBM_DatasetCreateFromSerializedReference(
ref_buffer: *const c_void,
ref_buffer_size: i32,
num_row: i64,
num_classes: i32,
parameters: *const c_char,
out: *mut DatasetHandle,
) -> c_intExpand description
Allocate the space for dataset and bucket feature bins according to serialized reference dataset.
Arguments
ref_buffer- A binary representation of the dataset schema (feature groups, bins, etc.)ref_buffer_size- The size of the reference array in bytesnum_row- Number of total rows the dataset will containnum_classes- Number of classes (will be used only in case of multiclass and specifying initial scores)parameters- Additional parametersout(direction out) - Created dataset
Returns
0 when succeed, -1 when failure happens